Welcome to the package of yonlu. The current version of yonlu 1.1.17.
For those who are interested in contributing to the development of yonlu, please contact at min.song@yonsei.ac.kr.

The current version of yonlu supports Korean and English text.